info_messages = {
    "unknown_command": "Unknown command.",
    "operation_cancelled": "Operation canceled.",
    "contact_added": "Contact added successfully.",
    "contact_not_added": "Failed to add contact.",
    "contact_edited": "Contact edited successfully.",
    "contact_deleted": "Contact deleted successfully.",
    "phone_added": "Phone added.",
    "phone_removed": "Phone removed.",
    "birthday_added": "Birthday added.",
    "birthday_removed": "Birthday removed.",
    "email_added": "Email added.",
    "email_removed": "Email removed.",
    "address_added": "Address added.",
    "address_removed": "Address removed.",
    "no_contacts": "Contacts not found.",
    "upcoming_birthdays": "You have {} upcoming birthday(s) in {} days.",
    "no_birthdays": "There are no upcoming birthdays in the next {} days.",
    "fake_contacts_generated": "Fake contacts generated successfully.",
    "note_added": "Note added successfully.",
    "note_edited": "Note edited successfully.",
    "note_deleted": "Note deleted successfully.",
    "text_added": "Text added.",
    "text_removed": "Text removed.",
    "tags_added": "Tags added.",
    "tag_removed": "Tag removed.",
    "reminder_added": "Reminder added.",
    "reminder_removed": "Reminder removed.",
    "no_notes": "There are no notes in the book.",
    "fake_notes_generated": "Fake notes generated successfully.",
    "reminders": "You have {} upcoming reminder(s) in {} days.",
    "no_reminders": "There are no reminders in the next {} days.",
}
