commands = {
    "add_contact": "add-contact",
    "change_contact": "change-contact",
    "add_phones": "add-phones",
    "remove_phone": "remove-phone",
    "add_birthday": "add-birthday",
    "remove_birthday": "remove-birthday",
    "edit_birthday": "edit-birthday",
    "add_email": "add-email",
    "remove_email": "remove-email",
    "edit_email": "edit-email",
    "add_address": "add-address",
    "remove_address": "remove-address",
    "edit_address": "edit-address",
    "delete_contact": "delete-contact",
    "all_contacts": "all-contacts",
    "birthdays": "birthdays",
    "fake_contacts": "fake-contacts",
    "help": "help",
    "search_contacts": "search-contacts",
    "smart_search": "smart-search",
    "main_menu": "main-menu",
    "add_tags": "add-tags",
    "remove_tag": "remove-tag",
    "add_text": "add-text",
    "remove_text": "remove-text",
    "edit_text": "edit-text",
    "add_reminder": "add-reminder",
    "remove_reminder": "remove-reminder",
    "edit_reminder": "edit-reminder",
}
